# belt
step 1: install scrcpy
        brew install scrcpy
step 2: install appium
        npm install -g appium
step 3: brew install node
        npm install -g ios-deploy
step 4: python install u requirements.txt

step 5: Start appium
